@@ -14,8 +14,11 @@
         $jffnms_rel_path = str_replace($jffnms_setup_page,"",$_SERVER["REQUEST_URI"]);
 
 	if (strpos($_SERVER["REQUEST_URI"],$jffnms_setup_page) === false) { 	//we are not in the setup page
-
-	    $jffnms_setup_location = "http://".$_SERVER["HTTP_HOST"].str_replace("//","/",$jffnms_rel_path.$jffnms_setup_page);
+        if ($_SERVER['HTTPS']) {
+            $jffnms_setup_location = "https://".$_SERVER["HTTP_HOST"].str_replace("//","/",$jffnms_rel_path.$jffnms_setup_page);
+        } else {
+            $jffnms_setup_location = "http://".$_SERVER["HTTP_HOST"].str_replace("//","/",$jffnms_rel_path.$jffnms_setup_page);
+        }
 	    header("Location: ".$jffnms_setup_location);			//redirect to setup
 	    die();    
 	} else 
