@@ -8,5 +8,5 @@
 
     //DISABLED because of new filtering on events (FIXME make this an option)
     //$return = make_events_latest($events_latest_max);
-    logger("Make Latest Events 1=OK: $return\n");
+    //logger("Make Latest Events 1=OK: $return\n");
 ?>
