@@ -9,8 +9,11 @@
 
 	$storage_devices = array();
 
+	$blocked_devices = array ("/dev", "/.vol");
+	
+
 	if ($ip && $hostid && $rocommunity)  
-	    $deviceIndex = snmp_walk("$ip","$rocommunity",".1.3.6.1.2.1.25.2.3.1.1");
+	    $deviceIndex = snmp_walk($ip, $rocommunity, ".1.3.6.1.2.1.25.2.3.1.1");
     
 	if (count($deviceIndex) > 0) {
 
@@ -70,24 +73,18 @@
 		    if (isset($deviceBlockSize[$i]) && isset($deviceBlockCount[$i])) 
 			$devInfo["size"] = $deviceBlockSize[$i] * $deviceBlockCount[$i];
 
-		    $label_hex = strpos($deviceDescription[$i],"Hex");
-		    if ($label_hex!==FALSE)   //UCD-SNMP 4.2.4 fix
-		        $deviceDescription[$i] = substr($deviceDescription[$i],0,$label_hex-1);
-		    
-		    $deviceDescription[$i]  = str_replace("\"","",$deviceDescription[$i]);  //UCD-SNMP 4.2.4 fix
-		    $deviceDescription[$i]  = str_replace("\\","",$deviceDescription[$i]); //Windows Hack for C:\ breaking the DB
 
-		    //Windows XP Disk Label Hack
-		    $label_pos = strpos($deviceDescription[$i],"Label");
-		    if ($label_pos!==FALSE) {  
-		        $devInfo["interface"] = substr($deviceDescription[$i],0,$label_pos-1); //strip the \ and the space
-		        $devInfo["description"] = substr($deviceDescription[$i],$label_pos,strlen($deviceDescription[$i])-$label_pos);
-		    } else 
-			$devInfo["interface"] = $deviceDescription[$i];
-    	    
+		    include_once(jffnms_shared("storage"));
+
+		    list ($devInfo["interface"], $devInfo["description"]) = storage_interface_parse_description ($deviceDescription[$i]);
+    
 		    foreach ($devInfo as $key=>$value) $devInfo[$key]=trim($value);
+
+		    if (in_array($devInfo["interface"], $blocked_devices)) //set blocked devices to size 0 so they don't get auto-discovered
+                	$devInfo["size"] = 0;
 	
-        	    if($devInfo["size"] > 0) {
+	
+        	    if ($devInfo["size"] > 0) {
             		$devInfo["admin"] = "up";
             		$devInfo["oper"] = "up";
             	    } else {
@@ -96,7 +93,6 @@
                     }
 		    
 		    $storage_devices[$deviceIndex[$i]] = $devInfo;
-		    //debug ($devInfo);
 		}
 	}
         //debug($storage_devices);
