@@ -24,9 +24,9 @@ function graph_traffic ($data) {
     
     $opts_GRAPH_init=array(
         "HRULE:".$data["bandwidthin"]. "#FF0000:' '",
-	"COMMENT:'Inbound Bandwidth: ".($data["bandwidthin"] /1000)." kbps'",     
+	"COMMENT:'Inbound Bandwidth\: ".($data["bandwidthin"] /1000)." kbps'",     
         "HRULE:".$data["bandwidthout"]."#AA0000:' '",
-	"COMMENT:'Outbound Bandwidth:".($data["bandwidthout"]/1000)." kbps".(!empty($data["address"])?"  IP: ".$data["address"]:"")."\\n'",     
+	"COMMENT:'Outbound Bandwidth\:".($data["bandwidthout"]/1000)." kbps".(!empty($data["address"])?"  IP: ".$data["address"]:"")."\\n'",     
     );	
 
     // External Data Gathering
