@@ -4,6 +4,7 @@
  * This program is licensed under the GNU GPL, full terms in the LICENSE file
  */
 
+
     $launcher_function = "real_poller";
     $launcher_param_normal_handler = "poller_params";
     $launcher_param_managed_handler = "poller_params_managed";
@@ -74,6 +75,16 @@
 	
 	$time_start = time_usec();
 
+    // Validate input
+    if ($host_id != NULL && !is_numeric($host_id)) {
+        logger("ERROR: Host '$host_id' is not NULL or numeric.\n");
+        return;
+    }
+    if ($interface_id != NULL && !is_numeric($interface_id) && $interface_id != 'dmii') {
+        logger("ERROR: Interface '$interface_id' is not NULL, numeric or dmii.\n");
+        return;
+    }
+
 	$poller_plan_filter = array("interface"=>$interface_id,"host"=>$host_id,"pos"=>$poller_pos,"type"=>$itype);
 	$poller_plan_result = poller_plan ($poller_plan_filter); // Get the Poller Plan (things to poll)
 
