@@ -29,7 +29,7 @@ function poller_tcp_status ($options) {
     } else {
 	socket_set_blocking($fp,FALSE); //try to read for 1 second
 	sleep(3);
-	$data = addslashes( trim (fgets ($fp,100)));
+	$data = preg_replace('/[^ -~]/', '', addslashes( trim (fgets ($fp,100))));
 	fclose ($fp);
 	$status = "open";
     }
