@@ -690,6 +690,55 @@
 	    NULL)
 	);
 
+    $structures['logfiles_match_items'] = array(
+        'title'=>'Log File Match Items',
+        'object'=>'logfiles_match_items',
+        'show_id'=>1,
+        'action_type'=>1,
+        'no_records_message'=>'No Log File Match Items Found',
+        'profile'=>'ADMIN_HOSTS',
+        'fields'=>array(
+            'description'=>array('name'=>'Description', 'type'=>'textbox', 'size'=>30, 'filter'=>false),
+            'match_text'=>array('name'=>'Text Match', 'type'=>'textbox', 'size'=>40, 'filter'=>false),
+            'host'=>array('name'=>'Host Field', 'type'=>'textbox', 'size'=>10, 'filter'=>false),
+            'interface'=>array('name'=>'Interface Field', 'type'=>'textbox', 'size'=>10, 'filter'=>false),
+            'username'=>array( 'name'=>'Username Field', 'type'=>'textbox', 'size'=>10, 'filter'=>false),
+            'state'=>array( 'name'=>'State Field',  'type'=>'textbox', 'size'=>10, 'filter'=>false),
+            'info'=>array( 'name'=>'Extra Info Field', 'type'=>'textbox', 'size'=>10, 'filter'=>false),
+            'type'=>array( 'name'=>'Event Type',  'type'=>'select', 'func'=>'select_event_types', 'view'=>'types_description', 'size'=>30),
+	    NULL)
+	);
+
+    $structures['logfiles'] = array(
+        'title'=>'Log Files',
+        'object'=>'logfiles',
+        'show_id'=>1,
+        'action_type'=>2,
+	    'hide_record_one'=>1,
+	    'split'=>'logfiles_match_groups',
+	    'split_standard'=>1,
+        'no_records_message'=>'No Log Files Found',
+        'profile'=>'ADMIN_HOSTS',
+
+        'fields'=>array(
+            'filename'=>array('name'=>'Filename', 'type'=>'textbox', 'size'=>60, 'filter'=>false),
+            NULL)
+    );
+    $structures['logfiles_match_groups'] = array(
+        'title'=>'Log File Match Group',
+        'object'=>'logfiles_match_groups',
+        'show_id'=>1,
+        'action_type'=>1,
+        'profile'=>'ADMIN_SYSTEM',
+
+        'fields'=>array(
+            'pos'=>array('name'=>'Position', 'type'=>'textbox', 'size'=>3, 'filter'=>false),
+            'match_item'=>array('name'=>'Match', 'type'=>'select', 'func'=>'select_logfiles_match_items', 'size'=>30, 'view'=>'logfile_match_description'),
+            NULL)
+    );
+
+	
+
     if ($admin_structure=="list_all") { 
 	foreach (array_keys($structures) as $aux) 
 	    echo tag("li").linktext($aux, "adm_standard.php?admin_structure=".$aux); 
@@ -698,5 +747,5 @@
 	if (is_array($structures[$admin_structure])) 
 	    $structure = $structures[$admin_structure];
 	else
-	    die(html("h1", "Admin Structure Not Found"));
+	    die(display_error("Admin Structure Not Found","JFFNMS attempted to find a structure called '".$admin_structure."' but was unable to. This is generally an internal error."));
 ?>
