@@ -465,6 +465,45 @@
         function delete()	{ $params = func_get_args(); return call_user_func_array("interfaces_delete_value",$params); }
     }
 
+    class jffnms_logfiles	extends internal_base_standard 	{ 
+	var $jffnms_class = "logfiles";  
+	var $jffnms_insert = array('filename'=>"new"); 
+	var $jffnms_filter_record = 0;
+	var $jffnms_order_type = "asc";
+    }
+    class jffnms_logfiles_match_groups	extends internal_base_standard 	{ 
+	var $jffnms_class = "logfiles_match_groups";  
+	var $jffnms_insert = array("pos"=>"10"); 
+	var $jffnms_filter_record = 0;
+	var $jffnms_order_type = "asc";
+
+	function add() 	{ 
+	    return db_insert($this->jffnms_class,array('logfile'=>$GLOBALS['filter'])); 
+	}
+    function get_all($ids = NULL)	{ 
+	    return get_db_list(	
+		array('logfiles', $this->jffnms_class, 'logfiles_match_items'),	$ids, 
+		array(	$this->jffnms_class.".*",
+			'logfile_match_description'=>'logfiles_match_items.description',
+		    ) ,	
+		array(	
+		    array($this->jffnms_class.'.logfile','=','logfiles.id'),
+		    array($this->jffnms_class.'.match_item','=','logfiles_match_items.id'),
+		    array($this->jffnms_class.'.id','>',1)),
+		
+		array(
+		    array('logfiles.id','asc'), 
+		    array($this->jffnms_class.'.pos','asc'), 
+		)); 
+	}
+    }
+    class jffnms_logfiles_match_items	extends internal_base_standard 	{ 
+	var $jffnms_class = "logfiles_match_items";  
+	var $jffnms_insert = array('match_text'=>'New Log Message Type','info'=>'*'); 
+	var $jffnms_filter_record = 0;
+	var $jffnms_order_type = "asc";
+    }
+
     class jffnms_nad extends basic {
 
         function get_data()	{ $params = func_get_args(); return call_user_func_array("nad_get_data",$params); }
@@ -677,7 +716,7 @@
     	    $auth_type = 1;
 	    $cant_auth = 0;
 	    
-	    if (isset($user) && isset($pass)) {
+	    if (preg_match("/^[\w\@\.]{0,20}$/", $user) && isset($pass)) {
 		$query_auth = "select id as auth_user_id, usern as auth_user_name, passwd, fullname as auth_user_fullname from auth where usern = '$user'";
 		$result_auth = db_query ($query_auth);
 		$cant_auth = db_num_rows($result_auth);
@@ -693,18 +732,20 @@
 	    } 
     
 	    if (($auth==0) && ($cant_auth == 0)){  //not found in DB
-		if (isset($user) && isset($pass)) {
+
+		if (preg_match("/^[\w\@\.]{0,20}$/", $user) && isset($pass)) {
     		    $query_auth = "select id as auth_user_id, username as auth_user_name, name as auth_user_fullname from clients where username= '$user' and password = '$pass'";
 		    $result_auth = db_query ($query_auth);
 		    $auth = db_num_rows( $result_auth);
 		}
+		
 		if ($auth==1) { 
 		    $reg = db_fetch_array($result_auth);
 		    $auth_type = 2;
 		}
 	    }
 	    
-	    if (($log_event==true) && (!empty($user)))
+	    if (($log_event==true) && preg_match("/^[\w\@\.]{0,20}$/", $user))
 		insert_event(date("Y-m-d H:i:s",time()),get_config_option("jffnms_internal_type"),1,"Login",(($auth==1)?"successful":"failed"),$user,$log_event_info,"",0);
 	    
 	    unset ($reg["passwd"]);
